Struct vapcore_miner::service_transaction_checker::ServiceTransactionChecker[][src]

pub struct ServiceTransactionChecker { /* fields omitted */ }

Service transactions checker.

Implementations

impl ServiceTransactionChecker[src]

pub fn check<C: CallContract + RegistrarClient>(
    &self,
    client: &C,
    tx: &SignedTransaction
) -> Result<bool, String>
[src]

Checks if given address in tx is whitelisted to send service transactions.

pub fn check_address<C>(
    &self,
    client: &C,
    sender: Address
) -> Result<bool, String> where
    C: CallContract + RegistrarClient
[src]

Checks if given address is whitelisted to send service transactions.

pub fn refresh_cache<C>(&self, client: &C) -> Result<bool, String> where
    C: CallContract + RegistrarClient
[src]

Refresh certified addresses cache