Enum vapcore_miner::pool::verifier::Transaction [−][src]
Transaction to verify.
Variants
Unverified(UnverifiedTransaction)Fresh, never verified transaction.
We need to do full verification of such transactions
Retracted(UnverifiedTransaction)Transaction from retracted block.
We could skip some parts of verification of such transactions
Local(PendingTransaction)Locally signed or retracted transaction.
We can skip consistency verifications and just verify readiness.
Implementations
impl Transaction[src]
pub fn hash(&self) -> H256[src]
Return transaction hash
pub fn gas_price(&self) -> &U256[src]
Return transaction gas price